﻿/*
 * Developer : Matt Smith (matt@matt40k.co.uk)
 * All code (c) Matthew Smith all rights reserved
 */

using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;

namespace Matt40k.SIMSLOAD
{
    public class Program
    {
        public static void Main()
        {
            if (File.Exists(Path.Combine(GetDirectory, "simsload.exe")))
                RunSimsLoad();
            else
                RunSimsAppSetup();
        }

        private static string GetDirectory
        {
            get
            {
                return Path.GetDirectoryName(Assembly.GetExecutingAssembly().GetName().CodeBase);
            }
        }

        private static void RunSimsLoad()
        {
            string _simsLoad = Path.Combine(GetDirectory, "simsload.exe");
            try
            {
                Process prc = new Process();
                prc.StartInfo.FileName = _simsLoad;
                prc.Start();
                prc.WaitForExit();
            }
            catch (Exception RunSimsLoad_Exception)
            {
                
            }
        }

        private static void RunSimsAppSetup()
        {
            string _simsIni = Path.Combine(windir, "SIMS.ini");
            if (File.Exists(_simsIni))
            {
                IniFile iniFile = new IniFile(Path.Combine(windir, "SIMS.ini"));
                string _setupDir = iniFile.Read("Setup", "SIMSSetupsDirectory");
                string _simsAppSetup = Path.Combine(_setupDir, "simsapplicationsetup.exe");
                if (File.Exists(_simsAppSetup))
                {
                    try
                    {
                        Process prc = new Process();
                        prc.StartInfo.FileName = _simsAppSetup;
                        prc.StartInfo.Arguments = "/S {QuietMode}";
                        prc.Start();
                        prc.WaitForExit();

                        RunSimsLoad();
                    }
                    catch (Exception RunSimsAppSetup_Exception)
                    {

                    }
                }
            }
        }

        /// <summary>
        /// Returns the Windows Directory
        /// </summary>
        private static string windir
        {
            get
            {
                return Environment.GetEnvironmentVariable("windir");
            }
        }
    }
}
